==> s-render-0.5.88.tgz: package/lib/FormRender/widgets/container/FileComponent/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/FormRender/widgets/container/FileComponent/index.tsx
var FileComponent_exports = {};
__export(FileComponent_exports, {
  default: () => FileComponent_default
});
module.exports = __toCommonJS(FileComponent_exports);
var import_icons = require("@ant-design/icons");
var import_antd = require("antd");
var import_react = require("react");
var import_zustand = require("zustand");
var import_context = require("../../../models/context");
var import_index = require("./index.less");
var isImageFileType = (type) => type.indexOf("image/") === 0;
var FileComponent = (props) => {
  const store = (0, import_react.useContext)(import_context.FormRenderContext);
  const { uploadConfig } = (0, import_zustand.useStore)(store, (state) => state.context) ?? {};
  const { schema, path } = props;
  const [previewVisible, setPreviewVisible] = (0, import_react.useState)(false);
  const [previewIndex, setPreviewIndex] = (0, import_react.useState)(0);
  const form = import_antd.Form.useFormInstance();
  const _fileList = import_antd.Form.useWatch(path, form);
  if (!uploadConfig) {
    console.error("请配置uploadConfig");
    return null;
  }
  const imageList = _fileList == null ? void 0 : _fileList.filter(
    (item) => isImageFileType(item == null ? void 0 : item.type) && (item == null ? void 0 : item.status) === "done" && (item == null ? void 0 : item.response)
  );
  const normFile = (e) => {
    if (Array.isArray(e)) {
      return e;
    }
    return e == null ? void 0 : e.fileList;
  };
  const customRequest = (info) => {
    const { onProgress, onSuccess, file, onError } = info;
    uploadConfig == null ? void 0 : uploadConfig.uploadRequest(file, onProgress).then((res) => {
      onSuccess(res, file);
    }).catch(() => {
      onError();
    });
  };
  const itemRender = (originNode, file, fileList, actions) => {
    var _a;
    if (file.type && isImageFileType(file.type)) {
      return /* @__PURE__ */ React.createElement("div", { className: "srender-image-wrapper" }, /* @__PURE__ */ React.createElement(
        import_antd.Image,
        {
          src: (file == null ? void 0 : file.thumbUrl) ?? ((_a = uploadConfig == null ? void 0 : uploadConfig.downloadImageUrl) == null ? void 0 : _a.call(uploadConfig, file == null ? void 0 : file.response)),
          preview: false
        }
      ), /* @__PURE__ */ React.createElement("div", { className: "srender-image-actions" }, /* @__PURE__ */ React.createElement(import_antd.Space, null, /* @__PURE__ */ React.createElement(import_icons.EyeOutlined, { onClick: actions.preview }), /* @__PURE__ */ React.createElement(import_icons.DeleteOutlined, { onClick: actions.remove }))));
    }
    return originNode;
  };
  const onPreview = (file) => {
    setPreviewVisible(true);
    const index = imageList == null ? void 0 : imageList.findIndex((item) => (item == null ? void 0 : item.uid) === (file == null ? void 0 : file.uid));
    setPreviewIndex(index);
  };
  return /* @__PURE__ */ React.createElement(import_antd.Col, { span: 24 }, /* @__PURE__ */ React.createElement(
    import_antd.Card,
    {
      size: "small",
      type: "inner",
      title: /* @__PURE__ */ React.createElement(
        "div",
        {
          className: (schema == null ? void 0 : schema.required) && "srender-file-component-required" || ""
        },
        schema == null ? void 0 : schema.title
      ),
      className: "srender-file-component"
    },
    /* @__PURE__ */ React.createElement(
      import_antd.Form.Item,
      {
        name: path,
        rules: [
          { required: schema == null ? void 0 : schema.required, message: `请上传${schema == null ? void 0 : schema.title}` }
        ],
        valuePropName: "fileList",
        getValueFromEvent: normFile
      },
      /* @__PURE__ */ React.createElement(
        import_antd.Upload.Dragger,
        {
          listType: "picture-card",
          customRequest,
          onDownload: uploadConfig == null ? void 0 : uploadConfig.downloadRequest,
          onPreview,
          showUploadList: {
            showPreviewIcon: false,
            showDownloadIcon: true
          },
          itemRender
        },
        /* @__PURE__ */ React.createElement("p", { className: "ant-upload-drag-icon" }, /* @__PURE__ */ React.createElement(import_icons.InboxOutlined, null)),
        /* @__PURE__ */ React.createElement("p", { className: "ant-upload-text" }, "单击或拖动文件到此区域进行上传")
      )
    )
  ), /* @__PURE__ */ React.createElement(
    import_antd.Image.PreviewGroup,
    {
      preview: {
        visible: previewVisible,
        current: previewIndex,
        onVisibleChange: (visible) => {
          setPreviewVisible(visible);
          setPreviewIndex(0);
        }
      },
      items: imageList == null ? void 0 : imageList.map(
        (item) => {
          var _a;
          return (item == null ? void 0 : item.thumbUrl) ?? ((_a = uploadConfig == null ? void 0 : uploadConfig.downloadImageUrl) == null ? void 0 : _a.call(uploadConfig, item == null ? void 0 : item.response));
        }
      )
    }
  ));
};
var FileComponent_default = FileComponent;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});

==> s-render-0.5.91.tgz: package/lib/FormRender/widgets/container/FileComponent/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/FormRender/widgets/container/FileComponent/index.tsx
var FileComponent_exports = {};
__export(FileComponent_exports, {
  default: () => FileComponent_default
});
module.exports = __toCommonJS(FileComponent_exports);
var import_icons = require("@ant-design/icons");
var import_antd = require("antd");
var import_react = require("react");
var import_zustand = require("zustand");
var import_context = require("../../../models/context");
var import_index = require("./index.less");
var isImageFileType = (type) => type.indexOf("image/") === 0;
var FileComponent = (props) => {
  const store = (0, import_react.useContext)(import_context.FormRenderContext);
  const { uploadConfig } = (0, import_zustand.useStore)(store, (state) => state.context) ?? {};
  const { schema, path } = props;
  const [previewVisible, setPreviewVisible] = (0, import_react.useState)(false);
  const [previewIndex, setPreviewIndex] = (0, import_react.useState)(0);
  const form = import_antd.Form.useFormInstance();
  const _fileList = import_antd.Form.useWatch(path, form);
  if (!uploadConfig) {
    console.error("请配置uploadConfig");
    return null;
  }
  const imageList = _fileList == null ? void 0 : _fileList.filter(
    (item) => isImageFileType(item == null ? void 0 : item.type) && (item == null ? void 0 : item.status) === "done" && (item == null ? void 0 : item.response)
  );
  const normFile = (e) => {
    if (Array.isArray(e)) {
      return e;
    }
    return e == null ? void 0 : e.fileList;
  };
  const customRequest = (info) => {
    const { onProgress, onSuccess, file, onError } = info;
    uploadConfig == null ? void 0 : uploadConfig.uploadRequest(file, onProgress).then((res) => {
      const { thumbUrl, ...other } = file;
      onSuccess(res, other);
    }).catch(() => {
      onError();
    });
  };
  const itemRender = (originNode, file, fileList, actions) => {
    var _a;
    if (file.type && isImageFileType(file.type)) {
      return /* @__PURE__ */ React.createElement("div", { className: "srender-image-wrapper" }, /* @__PURE__ */ React.createElement(
        import_antd.Image,
        {
          src: (file == null ? void 0 : file.thumbUrl) ?? ((_a = uploadConfig == null ? void 0 : uploadConfig.downloadImageUrl) == null ? void 0 : _a.call(uploadConfig, file == null ? void 0 : file.response)),
          preview: false
        }
      ), /* @__PURE__ */ React.createElement("div", { className: "srender-image-actions" }, /* @__PURE__ */ React.createElement(import_antd.Space, null, /* @__PURE__ */ React.createElement(import_icons.EyeOutlined, { onClick: actions.preview }), /* @__PURE__ */ React.createElement(import_icons.DeleteOutlined, { onClick: actions.remove }))));
    }
    return originNode;
  };
  const onPreview = (file) => {
    setPreviewVisible(true);
    const index = imageList == null ? void 0 : imageList.findIndex((item) => (item == null ? void 0 : item.uid) === (file == null ? void 0 : file.uid));
    setPreviewIndex(index);
  };
  return /* @__PURE__ */ React.createElement(import_antd.Col, { span: 24 }, /* @__PURE__ */ React.createElement(
    import_antd.Card,
    {
      size: "small",
      type: "inner",
      title: /* @__PURE__ */ React.createElement(
        "div",
        {
          className: (schema == null ? void 0 : schema.required) && "srender-file-component-required" || ""
        },
        schema == null ? void 0 : schema.title
      ),
      className: "srender-file-component"
    },
    /* @__PURE__ */ React.createElement(
      import_antd.Form.Item,
      {
        name: path,
        rules: [
          { required: schema == null ? void 0 : schema.required, message: `请上传${schema == null ? void 0 : schema.title}` }
        ],
        valuePropName: "fileList",
        getValueFromEvent: normFile
      },
      /* @__PURE__ */ React.createElement(
        import_antd.Upload.Dragger,
        {
          listType: "picture-card",
          customRequest,
          onDownload: uploadConfig == null ? void 0 : uploadConfig.downloadRequest,
          onPreview,
          showUploadList: {
            showPreviewIcon: false,
            showDownloadIcon: true
          },
          itemRender
        },
        /* @__PURE__ */ React.createElement("p", { className: "ant-upload-drag-icon" }, /* @__PURE__ */ React.createElement(import_icons.InboxOutlined, null)),
        /* @__PURE__ */ React.createElement("p", { className: "ant-upload-text" }, "单击或拖动文件到此区域进行上传")
      )
    )
  ), /* @__PURE__ */ React.createElement(
    import_antd.Image.PreviewGroup,
    {
      preview: {
        visible: previewVisible,
        current: previewIndex,
        onVisibleChange: (visible) => {
          setPreviewVisible(visible);
          setPreviewIndex(0);
        },
        onChange: (index) => {
          setPreviewIndex(index);
        }
      },
      items: imageList == null ? void 0 : imageList.map(
        (item) => {
          var _a;
          return (item == null ? void 0 : item.thumbUrl) ?? ((_a = uploadConfig == null ? void 0 : uploadConfig.downloadImageUrl) == null ? void 0 : _a.call(uploadConfig, item == null ? void 0 : item.response));
        }
      )
    }
  ));
};
var FileComponent_default = FileComponent;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
